#
# spec file for package rke2-1.26
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true
%define binary_name rke2

Name:           rke2-1.26
Version:        1.26.15+rke2r1
Release:        1.2
Summary:        Rancher Kubernetes Engine
License:        Apache-2.0
URL:            https://github.com/rancher/rke2
Source:         rke2-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.19
Provides:       rke2 = %{version}-%{release}
Conflicts:      rke2 < 1.26
Conflicts:      rke2 > 1.27

%description
RKE2, also known as RKE Government, is Rancher's next-generation Kubernetes distribution.
It is a fully conformant Kubernetes distribution that focuses on security and compliance within the U.S. Federal Government sector.

To meet these goals, RKE2 does the following:
    Provides defaults and configuration options that allow clusters to pass the CIS Kubernetes Benchmark with minimal operator intervention
    Enables FIPS 140-2 compliance
    Supports SELinux policy and Multi-Category Security (MCS) label enforcement
    Regularly scans components for CVEs using trivy in our build pipeline

%prep
%setup -q -n rke2-%{version}
%setup -q -T -D -a 1 -n rke2-%{version}

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="-X main.Version=%{version}"

%install
# Install the binary.
install -D -m 0755 %{binary_name} "%{buildroot}/%{_bindir}/%{binary_name}"

%files
%defattr(-,root,root)
%doc README.md
%license LICENSE
%{_bindir}/%{binary_name}

%changelog
* Thu Mar 21 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.26.15+rke2r1:
  * This release updates Kubernetes to v1.26.15, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.26.15+rke2r1
* Sat Mar 16 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.26.14+rke2r1:
  * This release updates Kubernetes to v1.26.14, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.26.14+rke2r1
* Tue Feb  6 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.26.13+rke2r1:
  * This release updates Kubernetes to v1.26.13, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.26.13+rke2r1
* Tue Feb  6 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.26.12+rke2r1:
  * This release updates Kubernetes to v1.26.12, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.26.12+rke2r1
* Thu Dec  7 2023 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.26.11+rke2r1:
  * This release updates Kubernetes to v1.26.11, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.26.11+rke2r1
* Thu Nov  9 2023 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.26.10+rke2r2:
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.26.10+rke2r2
* Fri Nov  3 2023 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.26.10+rke2r1:
  * This release updates Kubernetes to v1.26.10, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.26.10+rke2r1
* Tue Sep 19 2023 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.26.9+rke2r1:
  * This release updates Kubernetes to v1.26.9, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.26.9+rke2r1
* Fri Sep 15 2023 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.26.8+rke2r1:
  * This release updates Kubernetes to v1.26.8, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.26.8+rke2r1
* Fri Sep 15 2023 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.26.7+rke2r1:
  * This release updates Kubernetes to v1.26.7, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.26.7+rke2r1
* Fri Sep 15 2023 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.26.6+rke2r1:
  * This release updates Kubernetes to v1.26.6, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.26.6+rke2r1
* Fri Sep 15 2023 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.26.5+rke2r1:
  * This release updates Kubernetes to v1.26.5, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.26.5+rke2r1
* Fri Sep 15 2023 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.26.4+rke2r1:
  * This release updates Kubernetes to v1.26.4, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.26.4+rke2r1
* Fri Sep 15 2023 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.26.3+rke2r1:
  * This release updates Kubernetes to v1.26.3, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.26.3+rke2r1
* Fri Sep 15 2023 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.26.2+rke2r1:
  * This release updates Kubernetes to v1.26.2, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.26.2+rke2r1
* Fri Sep 15 2023 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.26.1+rke2r1:
  * This release updates Kubernetes to v1.26.1, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.26.1+rke2r1
* Fri Sep 15 2023 Johannes Kastl <kastl@b1-systems.de>
- rename package to rke2-1.26, as this stays on the 1.26.x series
  of Kubernetes
* Tue Nov 29 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.25.4+rke2r1:
  * This release updates Kubernetes to v1.25.4, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.25.4+rke2r1
* Tue Nov 29 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.25.3+rke2r1:
  * This release updates Kubernetes to v1.25.3, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.25.3+rke2r1
* Tue Nov 29 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.25.2+rke2r1:
  * This release updates Kubernetes to v1.25.2, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.25.2+rke2r1
- skipping non-existing release 1.25.1-rke2r1
* Thu Sep 15 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.25.0+rke2r1:
  * This release updates Kubernetes to v1.25.0, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.25.0+rke2r1
* Thu Sep  8 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.24.4+rke2r1:
  * This release updates Kubernetes to v1.24.4, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.24.4+rke2r1
* Thu Sep  8 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.24.3+rke2r1:
  * This release updates Kubernetes to v1.24.3, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.24.3+rke2r1
* Thu Sep  8 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.24.2+rke2r1:
  * This release updates Kubernetes to v1.24.2, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.24.2+rke2r1
* Thu Sep  8 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.24.1+rke2r1:
  * This release updates Kubernetes to v1.24.1, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.24.1+rke2r1
* Thu Sep  8 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.23.10+rke2r1:
  * This release updates Kubernetes to v1.23.10, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.23.10+rke2r1
* Thu Sep  8 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.23.9+rke2r1:
  * This release updates Kubernetes to v1.23.9, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.23.9+rke2r1
* Thu Sep  8 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.23.8+rke2r1:
  * This release updates Kubernetes to v1.23.8, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.23.8+rke2r1
* Thu Sep  8 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.23.7+rke2r1:
  * This release updates Kubernetes to v1.23.7, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.23.7+rke2r1
* Thu Sep  8 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.23.6+rke2r1:
  * This release updates Kubernetes to v1.23.6, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.23.6+rke2r1
* Thu Sep  8 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.23.5+rke2r1:
  * This release updates Kubernetes to v1.23.5, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.23.5+rke2r1
* Thu Sep  8 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.23.4+rke2r1:
  * This release updates Kubernetes to v1.23.4, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.23.4+rke2r1
* Thu Sep  8 2022 Johannes Kastl <kastl@b1-systems.de>
- build using -buildmode=pie
* Thu Sep  8 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.23.3+rke2r1:
  * This release updates Kubernetes to v1.23.3, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.23.3+rke2r1
* Thu Sep  8 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.23.2+rke2r1:
  * This release updates Kubernetes to v1.23.2, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.23.2+rke2r1
* Thu Sep  8 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.23.1+rke2r1:
  * This release updates Kubernetes to v1.23.1, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.23.1+rke2r1
* Thu Sep  8 2022 Johannes Kastl <kastl@b1-systems.de>
- BuildRequire go1.16, as upstream does in go.mod
* Thu Sep  8 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.22.11+rke2r1:
  * This release updates Kubernetes to v1.22.11, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.22.11+rke2r1
* Thu Sep  8 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.22.11+rke2r1:
  * This release updates Kubernetes to v1.22.11, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.22.11+rke2r1
* Thu Sep  8 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.22.10+rke2r1:
  * This release updates Kubernetes to v1.22.10, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.22.10+rke2r1
* Thu Sep  8 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.22.9+rke2r1:
  * This release updates Kubernetes to v1.22.9, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.22.9+rke2r1
* Thu Sep  8 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.22.8+rke2r1:
  * This release updates Kubernetes to v1.22.8, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.22.8+rke2r1
* Thu Sep  8 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.22.7+rke2r1:
  * This release updates Kubernetes to v1.22.7, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.22.7+rke2r1
* Thu Sep  8 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.22.6+rke2r1:
  * This release updates Kubernetes to v1.22.6, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.22.6+rke2r1
* Wed Jan  5 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.22.5+rke2r1:
  * This release updates Kubernetes to v1.22.5, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.22.5+rke2r1
* Wed Jan  5 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.22.4+rke2r1:
  * This release updates Kubernetes to v1.22.4, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.22.4+rke2r1
* Wed Jan  5 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.22.3+rke2r1:
  * This release updates Kubernetes to v1.22.3, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.22.3+rke2r1
* Wed Jan  5 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.21.8+rke2r1:
  * This release updates Kubernetes to v1.21.8, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.21.8+rke2r1
* Wed Jan  5 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.21.7+rke2r1:
  * This release updates Kubernetes to v1.21.7, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.21.7+rke2r1
* Wed Jan  5 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.21.6+rke2r1:
  * This release updates Kubernetes to v1.21.6, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.21.6+rke2r1
* Wed Jan  5 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.21.5+rke2r1:
  * This release updates Kubernetes to v1.21.5, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.21.5+rke2r1
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 1.21.4+rke2r1:
  * This release updates Kubernetes to v1.21.4, and fixes a number
    of issues.
  * Details see
    https://github.com/rancher/rke2/releases/tag/v1.21.4+rke2r1
* Thu Jul 29 2021 Johannes Kastl <kastl@b1-systems.de>
- initial version of package rke2 (version 1.21.3+rke2r1)
